frame .main_menu
pack .main_menu -expand yes -fill both

# menu.tcl, GRASS6 v 0.1 2004/02/17 Michael Barton 
# based on menu.tcl for GRASS5 by Hamish and Markus Neteler

# menus used several times in the main menu

set monitors_menu {
    "Start" "" {
        "All active saved X" "" {start_monitors}
        -separator
        X0 "" {"start_monitor x0"}
        X1 "" {"start_monitor x1"}
        X2 "" {"start_monitor x2"}
        X3 "" {"start_monitor x3"}
        X4 "" {"start_monitor x4"}
        X5 "" {"start_monitor x5"}
        X6 "" {"start_monitor x6"}
        -separator
        CELL "" {"exec  d.mon start=CELL"}
    }
    "Stop" "" {
        "All X" "" {stop_monitors}
        -separator
        X0 "" {"stop_monitor x0"}
        X1 "" {"stop_monitor x1"}
        X2 "" {"stop_monitor x2"}
        X3 "" {"stop_monitor x3"}
        X4 "" {"stop_monitor x4"}
        X5 "" {"stop_monitor x5"}
        X6 "" {"stop_monitor x6"}
        -separator
        CELL "" {"exec  d.mon stop=CELL"}
    }
    "Select" "" {
        X0 "" {"exec  d.mon select=x0"}
        X1 "" {"exec  d.mon select=x1"}
        X2 "" {"exec  d.mon select=x2"}
        X3 "" {"exec  d.mon select=x3"}
        X4 "" {"exec  d.mon select=x4"}
        X5 "" {"exec  d.mon select=x5"}
        X6 "" {"exec  d.mon select=x6"}
        -separator
        CELL "" {"exec  d.mon select=CELL"}
    }
    "Manage display monitors" "" {
        "exec d.mon &"
    }
}

set display_raster {
    "Display raster maps" "" {
        "exec d.rast &"
    }
    "Display HIS values" "" {
        "exec  d.his &"
    }
    "Display RGB overlays" "" {
        "exec  d.rgb &"
    }
    "Display profile" "" {
        "exec  d.profile &"
    }
}

set display_vector {
    "Display vector maps" "" {
        "exec  d.vect &"
    }
}

set display_sites {""
}

set image_processing {
    "Create/edit imagery group" "" {
        "exec i.group &"
    }
    "Target imagery group" "" {
        "exec i.target &"
    }
    -separator
    "Display" "" {
         "Display color image from RGB files" "" {
             "exec d.rgb &"
         }
         "Display color image from HIS files" "" {
             "exec d.his &"
         }
         "Create composite RGB image file" "" {
             "exec r.composite &"
         }
         "Transform RGB files to HIS" "" {
             "exec r.composite &"
         }
         "Transform HIS files to RGB" "" {
             "exec r.composite &"
         }
    }
    "Rectification" "" {
         "Setting ground control points (GCPs)" "" {
             "run i.points &"
         }
         "Affine and Polynomial transformation" "" {
             "exec i.rectify &"
         }
         "Ortho photo rectification" "" {
             "run i.ortho.photo &"
         }
    }
    "Image filtering" "" {
         "Zero edge crossing detection" "" {
             "exec  i.zc &"
         }
         "User defined matrix filter" "" {
             "exec  r.mfilter &"
         }
	 "Assign a histrogram contrast stretch qrey scale" "" {
	     "exec  r.colors &"
	 }
    }
    "Image transformation" "" {
         "Canonical component" "" {
             "exec  i.cca &"
         }
         "Principal component" "" {
             "exec  i.pca &"
         }
         "Fast Fourier Transform" "" {
             "exec  i.fft &"
         }
         "Inverse Fast Fourier Transform" "" {
             "exec  i.ifft &"
         }
    }
    "Classification" "" {
         "Clustering input for unsupervised classification" "" {
             "exec  i.cluster &"
         }
         "Interactive input for supervised classification" "" {
             "run i.class &"
         }
         "Non-interactive input for supervised classification (MLC)" "" {
             "exec  i.gensig &"
         }
         "Non-interactive input for supervised classification (SMAP)" "" {
             "exec  i.gensigset &"
         }
         -separator
         "Maximum likelyhood classification (MLC)" "" {
             "exec  i.maxlik &"
         }
         "Sequential maximum a posteriory classification (SMAP)" "" {
             "exec  i.smap &"
         }
    }
    "Areal photography" "" {
         "Mark fiducial/reseau points" "" {
             "exec  photo.2image &"
         }
         "Mark ground control points" "" {
             "exec  photo.2target &"
         }
         "Create/modify camera reference file" "" {
             "exec  photo.camera &"
         }
         "Create/modify camera exposure station for oblique photos" "" {
             "exec  photo.init &"
         }
         "Rectify aerial photo" "" {
             "exec  photo.rectify &"
         }
    }
}

set misc {""
}

# main menu

menu_build 1 .main_menu {
    Config "Configuration of TclTkGRASS" {
        "Monitors" "" $monitors_menu
        "Module windows" "" {
            "Automatic size for all active windows" "" {
                "resize_menu; resize $module_list"
            }
            "Reinitialize all active windows" "" {
                "resize_menu; reinit_modules"
            }
            -separator
            "Undisplay all active windows" "" {
                "unmap_modules"
            }
            "Restore all undisplayed windows" "" {
                "map_modules"
            }
            -separator
            "Iconify all active windows" "" {
                "foreach module $module_list {catch {wm iconify .$module; \
                                                     wm iconify .$module.print}}"
            }
            "Deiconify all active windows" "" {
                "foreach module $module_list {catch {wm deiconify .$module; \
                                                     wm deiconify .$module.print}}"
            }
            -separator
            "Destroy all active windows" "" {
                "foreach module $module_list {catch {destroy .$module}}"
            }
        }
        "Resize menu" "" {resize_menu}
        -separator
	"Scripting" "" {
	    "Start scripting" "" {
		"script_start"
	    }
	    "Stop scripting"  "" {
		"script_stop"
	    }
	    "Play script"     "" {
		"script_play"
	    }
	}
	-separator
        "Options" "" {
            "Menu font" "" {
                "fontsel {Menu font} main_menu(font);\
                 setfont .main_menu $main_menu(font);\
                 resize_menu"
            }
            "Module font" "" {
                "fontsel {Module font} module_font;\
                 foreach module $module_list {setfont .$module $module_font} ;\
                 resize $module_list"
            }
            "Results font" "" {
                "fontsel {Result font} result_font"
            }
            "Dialog font" "" {
                "fontsel {Dialog font} dialog_font"
            }
            -separator
            "Display dimensions" "" {
                "setdisplay"
            }
	    -separator
	    "Configure html-browser" "" {
		"config_netscape"
	    }
        }
        -separator
        "Save config" "" {
            "tcltkgrass_save ."
        }
    }
    Map "Map management (map files operations)" {
        "List" "" {
            "exec  g.list &"
        }
        "Copy" "" {
            "exec  g.copy &"
        }
        "Rename" "" {
            "exec  g.rename &"
        }
        "Remove" "" {
            "exec  g.remove &"
        }
        -separator
        "Mapset access" "" {
            "run g.access &"
        }
        "Mapset search path" "" {
            "exec  g.mapsets &"
        }
        -separator
        "Create/edit Imagery Group" "" {
            "exec i.group &"
        }
        "Target Imagery Group" "" {
            "exec i.target &"
        }
    }
    Region "Region coordinates management" {
        "ZOOM/UNZOOM in the monitor" "" {
            "exec  d.zoom &"
        }
        "PAN in the monitor" "" {
            "exec  d.pan &"
        }
        -separator
        "Display region settings" "" {
            "run g.region -p &"
        }
        "Select default region" "" {
            "run g.region -d; exec d.erase &"
        }
        "Manage region" "" {
            "exec  g.region &"
        }
    }
    Display "Display maps" {
        Monitors "" $monitors_menu
        "Redraw active monitor" "" {
            "run  d.redraw &"
        }
        "Save current map configuration as shell script" "" {
            "exec  d.save &"
        }
        -separator
        Raster "" $display_raster
        Vector "" $display_vector
        Text "" {
            "Display legend" "" {
                "exec  d.legend &"
            }
            "Display text labels for paint output" "" {
                "exec  d.paint.labels &"
            }
            "Select text font" "" {
                "exec  d.font &"
            }
            "Draw text" "" {
                "exec  d.text &"
            }
        }
        Graphics "" {
            "Display color table" "" {
                "exec  d.colortable &"
            }
            "Display geodesic line" "" {
                "exec  d.geodesic &"
            }
            "Display rhumbline" "" {
                "exec  d.rhumbline &"
            }
            "Overlay bar scale and north arrow" "" {
                "exec  d.barscale &"
            }
            "Overlay grid" "" {
                "exec  d.grid &"
            }
            "Display histogram" "" {
                "exec  d.histogram &"
            }
            "Display legend" "" {
                "exec  d.legend &"
            }
        }
        "Geographical position" "" {
            "run  d.where &"
        }
        -separator
        "NVIZ visualization tool" "" {
            "exec  nviz -q &"
        }
        "ERASE display frame" "" {
            "exec  d.erase &"
        }
        "ZOOM/UNZOOM in the monitor" "" {
            "run  d.zoom &"
        }
        "Manage display frames" "" {
            "exec  d.frame &"
        }
        "Manage colormode" "" {
            "exec  d.colormode &"
        }
    }
    Raster "Raster map analysis" {
        Display "" $display_raster
        "Analyse map" "" {
            "Query with mouse" "" {
                "run  d.what.rast &"
            }
            "Query with definition file" "" {
                "exec  r.what &"
            }
            "Display profile" "" {
                "exec  d.profile &"
            }
            "Measure lengths and areas" "" {
                "run  d.measure &"
            }
            "Overlay maps" "" {
                "Cross product" "" {
                    "exec  r.cross &"
                }
                "Patch maps" "" {
                    "exec  r.patch &"
                }
                "Aggregate functions of multiple maps" "" {
                    "exec  r.series &"
                }
                "Map calculator" "" {
                    "run r.mapcalc &"
                }
            }
            "Neighborhood tools" "" {
                "Neighborhood analysis" "" {
                    "exec  r.neighbors &"
                }
                "Buffer zone" "" {
                    "exec  r.buffer &"
                }
                "Grow areas" "" {
                    "exec  r.grow &"
                }
                "Clump contiguous cells" "" {
                    "exec  r.clump &"
                }
                "Thin linear features" "" {
                    "exec  r.thin &"
                }
            }
            "Terrain tools" "" {
                "Slope and aspect" "" {
                    "exec  r.slope.aspect &"
                }
                "Create shaded raster map" "" {
                    "exec  d.his &"
                }
                "Line of sight" "" {
                    "exec  r.los &"
                }
                "Cost between 2 locations" "" {
                    "exec  r.cost &"
                }
                "Trace minimum cost flow between two points" "" {
                    "exec  r.drain &"
                }
                -separator
                "Watershed subbasins" "" {
                    "exec  r.basins.fill &"
                }
                "Create watershed basins" "" {
                    "exec  r.water.outlet &"
                }
                "Calculate flow directions" "" {
                    "exec  r.fill.dir &"
                }
                "Hydrologic modeling" "" {
                    "exec  r.topmodel &"
                }
                "Terrain and watershed analysis" "" {
                    "exec  r.terraflow &"
                }
                -separator
                "Texture analysis" "" {
                    "exec  r.texture &"
                }
                "Topographic index" "" {
                    "exec  r.topidx &"
                }
                -separator
                "Anisotropic spread" "" {
                    "exec  r.spread &"
                }
                "Rate of spread calculations" "" {
                    "exec  r.ros &"
                }
                "Trace least cost spread path" "" {
                    "exec  r.spreadpath &"
                }
            }
        }
        "Extract vector map" "" {
            "exec  r.to.vect &"
        }
        "Develop map" "" {
            "Reclassify categories" "" {
                "exec  r.reclass &"
            }
            "Rescale categories" "" {
                "exec  r.rescale &"
            }
            "Average calculation" "" {
                "exec  r.average &"
            }
            "Statistical calculations" "" {
                "exec  r.statistics &"
            }
            "Clump small areas" "" {
                "exec  r.clump &"
            }
            -separator
            "Create color table or histogram contrast grey scale" "" {
                "exec  r.colors &"
            }
            "Modify color table" "" {
                "exec  d.colors &"
            }
            -separator
            "Digitize" "" {
                "run r.digit &"
            }
            "Edit cell values" "" {
                "run d.rast.edit &"
            }
            -separator
            "Map calculator" "" {
                "run r.mapcalc &"
            }
            "Resample (change resolution)" "" {
                "exec  r.resample &"
            }
            "Randomly located sites" "" {
                "exec  r.random &"
            }
            -separator
            "Interpolate using IDW" "" {
                "exec  r.surf.idw &"
            }
            "Interpolate from rasterized contours" "" {
                "exec  r.surf.contour &"
            }
            "Interpolate from vectorized contours" "" {
                "exec  v.surf.rst &"
            }
            -separator
            "Compress/decompress raster file" "" {
                "exec  r.compress &"
            }
        }
        "Report map" "" {
            "Basic information" "" {
                "exec  r.info &"
            }
            -separator
            "General statistics" "" {
                "exec  r.stats &"
            }
            "Category labels and values" "" {
                "exec  r.cats &"
            }
            "Category range" "" {
                "exec  r.describe &"
            }
            -separator
            "Area" "" {
                "exec  r.report &"
            }
            "Mutual category occurences (Coincidence)" "" {
                "run  r.coin &"
            }
            "Values on transect lines" "" {
                "exec  r.profile &"
            }
            "Values on transect lines (use azimuth, distance)" "" {
                "exec  r.transect &"
            }
            "Covariance/correlation" "" {
                "exec  r.covar &"
            }
        }
        -separator
        "Image processing" "" $image_processing
    }
    Vector "Vector map analysis" {
        "Display" "" $display_vector
        "Analyse map" "" {
                "Query with mouse" "" {
                       "run  d.what.vect &"
                }
                "Measure lengths and areas" "" {
                       "run  d.measure &"
                }
                "Buffer vector features" "" {
                       "exec  v.buffer &"
                }
                "Extract features" "" {
                       "exec  v.extract &"
                }
                "Select features" "" {
                       "exec  v.select &"
                }
                "Find nearest features" "" {
                       "exec  v.distance &"
                }
                "Combine maps (simple overlay of vector maps)" "" {
     		       "exec  v.patch &"
                }
	        "Overlay vector maps using boolean operations" "" {
        	       "exec  v.overlay &"
                }
        }
        "Network analysis" "" {
                "Network maintenance" "" {
                       "exec  v.net &"
                }
                "Split net to bands between cost isolines" "" {
                       "exec  v.net.iso &"
                }
                "Find shortest route" "" {
                       "exec  v.net.path &"
                }
                "Traveling salesman analysis" "" {
                       "exec  v.net.salsman &"
                }
                "Create Steiner tree" "" {
                       "exec  v.net.steiner &"
                }
                "Allocate subnets" "" {
                       "exec  v.net.alloc &"
            }
        }
        "Convert map" "" {
            "To raster format" "" {
                "exec  v.to.rast &"
            }
            "Interpolate raster surface map from contours" "" {
                "exec  v.surf.rst &"
            }
            "To points" "" {
                "exec  v.to.points &"
            }
        }
        "Develop map" "" {
            "Create/rebuild topology" "" {
                "exec  v.build &"
            }
            "Clean vector files" "" {
                "exec  v.clean &"
            }
            "Build polylines" "" {
                "exec  v.build.polylines &"
            }
            "Attach/delete/report vector categories" "" {
                "exec  v.category &"
            }
            "Use SQL to change vector categories" "" {
                "exec  v.reclass &"
            }
            "Set/print database connection for vector map" "" {
                "exec  v.db.connect &"
            }            
            "Set default driver/database for new vector attributes" "" {
                "exec  v.database &"
            }            
            -separator
            "Change projection on ASCII vector" "" {
                "exec  v.proj &"
            }
            "Coordinate tranformation on ASCII vector" "" {
                "exec  v.transform &"
            }
            "Convert map from old GRASS vector format to new format" "" {
                "exec  v.convert &"
            }
            "Import ASCII vector map into GRASS vector format" "" {
                "exec v.in.ascii &"
            }
            "Formatted ASCII file" "" {
                "exec v.in.region &"
            }
            "Create points from xy coordinates in database" "" {
                "exec  v.in.db &"
            }
            "Create vector map from current region" "" {
                "exec v.out.ascii &"
            }
            "Interface to register ESRI shapefiles and define PostGRASS connection" "" {
                "exec v.format &"
            }
            -separator
            "Digitize" "" {
                "exec v.digit &"
            }
        }
        "Report map" "" {
            "Basic information" "" {
                "exec  v.info &"
            }
            "Attach/delete/report vector categories" "" {
                "exec  v.category &"
            }
        }
    }
    Image "Image processing" $image_processing
    Import "Import maps into GRASS" {
        "Raster map" "" {
            "ERDAS LAN" "" {
                "exec  i.in.erdas &"
            }
            "Various formats (GDAL supported)" "" {
                "exec  r.in.gdal &"
            }
            -separator
            "Binary file (GTOPO30 format) in a lat-lon region" "" {
                "exec  r.in.bin &"
            }
        }
        "Vector map" "" {
            "ASCII GRASS vector file" "" {
                "exec  v.in.ascii &"
            }
            "Import/export old GRASS vector format" "" {
                "exec  v.convert &"
            }
            "Register ESRI shapefile" "" {
                "exec  v.shape.register &"
            }
            "Unregister ESRI shapefile" "" {
                "exec  v.shape.unregister &"
            }
            "GRASS sites list" "" {
                "exec  v.in.sites &"
            }
            "Various OGR formats" "" {
                "exec v.in.ogr &"
            }
        }
        "Site data" "" {
            "ASCII file/spot heights" "" {
                "exec  s.in.ascii &"
            }
        }
    }
    Export "Export maps from GRASS" {
        "Raster map" "" {
            "TIFF (8/24bit)" "" {
                "exec  r.out.tiff &"
            }
            "Binary file" "" {
                "exec  r.out.bin &"
            }
            "ESRI ARC/INFO ASCII-GRID" "" {
                "exec  r.out.arc &"
            }
            "PPM (24bit)" "" {
                "exec  r.out.ppm &"
            }
            "GRASS ASCII" "" {
                "exec  r.out.ascii &"
            }
            "ERDAS/LAN" "" {
                "exec  i.out.erdas &"
            }
            "GRASS CELL file as TIFF" "" {
                "exec  cell.out.tiff &"
            }
        }
        "Vector map" "" {
            "ASCII GRASS vector file" "" {
                "exec  v.out.ascii &"
            }
            "Import/export old GRASS vector format" "" {
                "exec  v.convert &"
            }
            "POV-Ray format" "" {
                "exec  v.out.pov &"
            }
            "Various OGR formats" "" {
                "exec v.out.ogr &"
            }
        }
        "Site data" "" {
            "ASCII file" "" {
                "exec  s.out.ascii &"
            }
        }
    }
    MapCreating MapCreating {
        "Postscript map creation" "" {
            "exec  ps.map &"
        }
        "Xfig (external)" "" {
            "run xfig &"
        }
    }
    Databases "Databases" {
        "List drivers" "" {
            "exec  db.connect.driver &"
        }
        "List available databases" "" {
            "exec  db.databases &"
        }
        "Connect to database" "" {
            "exec  db.connect &"
        }
        "Create empty database" "" {
            "exec  db.createdb &"
        }
        "Remove a database" "" {
            "exec  db.dropdb &"
        }
        "Copy table" "" {
            "exec  db.copy &"
        }
        "Remove a table" "" {
            "exec  db.droptable &"
        }
        -separator
        "List tables" "" {
            "exec  db.tables &"
        }	    	    
        "List columns" "" {
            "exec  db.columns &"
        }
        "Describe table" "" {
            "exec  db.describe &"
        }
        -separator	    
        "Select data" "" {
            "exec  db.select &"
        } 
        "Execute SQL statement" "" {
            "exec  db.execute &"
        }
        -separator
        "Set default driver/database for new vector attributes" "" {
            "exec  v.database &"
        }
        "Print/set database connection for a vector map" "" {
            "exec  v.db.connect &"
        }
        "Load values from vector to database" "" {
            "exec  v.to.db &"
        }	    	    
    }
    Help Help {
        "Manual pages" "" {
           "exec  g.manual &"
        }
    }
    Quit Bye quit
}
